summaryrefslogtreecommitdiff
path: root/include/internal/routines/level2/xhemv.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/internal/routines/level2/xhemv.h')
-rw-r--r--include/internal/routines/level2/xhemv.h17
1 files changed, 4 insertions, 13 deletions
diff --git a/include/internal/routines/level2/xhemv.h b/include/internal/routines/level2/xhemv.h
index 311ad9f8..b74db760 100644
--- a/include/internal/routines/level2/xhemv.h
+++ b/include/internal/routines/level2/xhemv.h
@@ -7,10 +7,9 @@
// Author(s):
// Cedric Nugteren <www.cedricnugteren.nl>
//
// This file implements the Xhemv routine. It is based on the generalized matrix multiplication
// routine (Xgemv). The Xhemv class inherits from the templated class Xgemv, allowing it to call the
-// "DoGemm" function directly. The "DoHemv" function first preprocesses the hermetian matrix by
-// transforming it into a general matrix, and then calls the regular GEMV code.
+// "MatVec" function directly.
//
// =================================================================================================
@@ -27,16 +26,8 @@ template <typename T>
class Xhemv: public Xgemv<T> {
public:
- // Members and methods from the base class
- using Routine<T>::db_;
- using Routine<T>::context_;
- using Routine<T>::GetProgramFromCache;
- using Routine<T>::TestMatrixA;
- using Routine<T>::RunKernel;
- using Routine<T>::ErrorIn;
-
- // Uses the regular Xgemv routine
- using Xgemv<T>::DoGemv;
+ // Uses the generic matrix-vector routine
+ using Xgemv<T>::MatVec;
// Constructor
Xhemv(Queue &queue, Event &event, const std::string &name = "HEMV");
@@ -7,10 +7,9 @@
// Cedric Nugteren <www.cedricnugteren.nl>
//
-// This file implements the Xhemv routine. It is based on the generalized matrix multiplication
+// This file implements the Xhemv routine. It is based on the generalized mat-vec multiplication
// routine (Xgemv). The Xhemv class inherits from the templated class Xgemv, allowing it to call the